pub enum StartExportTaskError {
DBClusterSnapshotNotFoundFault(String),
DBSnapshotNotFoundFault(String),
ExportTaskAlreadyExistsFault(String),
IamRoleMissingPermissionsFault(String),
IamRoleNotFoundFault(String),
InvalidExportOnlyFault(String),
InvalidExportSourceStateFault(String),
InvalidS3BucketFault(String),
KMSKeyNotAccessibleFault(String),
}Expand description
Errors returned by StartExportTask
Variants
DBClusterSnapshotNotFoundFault(String)
DBClusterSnapshotIdentifier doesn't refer to an existing DB cluster snapshot.
DBSnapshotNotFoundFault(String)
DBSnapshotIdentifier doesn't refer to an existing DB snapshot.
ExportTaskAlreadyExistsFault(String)
You can't start an export task that's already running.
IamRoleMissingPermissionsFault(String)
The IAM role requires additional permissions to export to an Amazon S3 bucket.
IamRoleNotFoundFault(String)
The IAM role is missing for exporting to an Amazon S3 bucket.
InvalidExportOnlyFault(String)
The export is invalid for exporting to an Amazon S3 bucket.
InvalidExportSourceStateFault(String)
The state of the export snapshot is invalid for exporting to an Amazon S3 bucket.
InvalidS3BucketFault(String)
The specified Amazon S3 bucket name can't be found or Amazon RDS isn't authorized to access the specified Amazon S3 bucket. Verify the SourceS3BucketName and S3IngestionRoleArn values and try again.
KMSKeyNotAccessibleFault(String)
An error occurred accessing an Amazon Web Services KMS key.
Implementations
Sourceimpl StartExportTaskError
impl StartExportTaskError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<StartExportTaskError>